package ca.uwaterloo.gp.editorlist;

/**********************************************************************
Copyright (c) 2002 IBM Corp.  All rights reserved.
This file is made available under the terms of the Common Public License v1.0
which accompanies this distribution, and is available at
http://www.eclipse.org/legal/cpl-v10.html
*********************************************************************/

import java.net.MalformedURLException;
import java.net.URL;

import org.eclipse.core.runtime.Platform;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.dialogs.IInputValidator;
import org.eclipse.jface.dialogs.InputDialog;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.ui.PlatformUI;

/**
 * The CreateEditorWorkingSetAction allows the user to
 * create a working set composed of the currently selected
 * files in the EditorList view.
 */
public class CreateEditorWorkingSetAction extends Action {

	EditorList fView;

	public CreateEditorWorkingSetAction(EditorList viewPart) {
		URL url = null;
		try {
			url = new URL(Platform.getBundle("EditorList").getEntry("/"), "icons/full/clcl16/create_workingset.gif"); //$NON-NLS-1$ //$NON-NLS-2$
		} catch (MalformedURLException e) {
		}
		setImageDescriptor(ImageDescriptor.createFromURL(url));
		setDescription(EditorListMessages.getString("CreateEditorWorkingSetAction.Create_a_working_set_1")); //$NON-NLS-1$
		setToolTipText(EditorListMessages.getString("CreateEditorWorkingSetAction.Create_working_set_1")); //$NON-NLS-1$
		setText(EditorListMessages.getString("CreateEditorWorkingSetAction.Create_working_set_2")); //$NON-NLS-1$
		fView= viewPart;
	}

	/**
	 * @see IAction#run()
	 */
	public void run() {
		InputDialog dialog= new InputDialog(fView.getViewSite().getShell(), EditorListMessages.getString("CreateEditorWorkingSetAction.Working_Set_Name_3"), EditorListMessages.getString("CreateEditorWorkingSetAction.Choose_a_name_for_the_working_set_4"), "", new IInputValidator() { //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
			public String isValid(String newString) {
				if (PlatformUI.getWorkbench().getWorkingSetManager().getWorkingSet(newString) != null) {
					return EditorListMessages.getString("CreateEditorWorkingSetAction.A_working_set_of_that_name_already_exists_6"); //$NON-NLS-1$
				}
				return null;
			}
		});
		dialog.open();
		String name= dialog.getValue();
		if (name != null && !(name.length() == 0)) {
			fView.createWorkingSetFromSelectedEditors(name);
		}
	}

}
